ScipySparseAnchorSearcher
=========================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: ScipySparseAnchorSearcher
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ScipySparseAnchorSearcher.__call__
      ~ScipySparseAnchorSearcher.bfs
      ~ScipySparseAnchorSearcher.create_adjacency
      ~ScipySparseAnchorSearcher.extra_repr
      ~ScipySparseAnchorSearcher.select

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: bfs
   .. automethod:: create_adjacency
   .. automethod:: extra_repr
   .. automethod:: select
